EffectMachine

Struct EffectMachine 

pub struct EffectMachine<'a> { /* private fields */ }

Implementations

Source

impl<'a> EffectMachine<'a>

pub fn new( table: &'a DataConTable, heap: &'a mut dyn Heap, ) -> Result<Self, EffectError>

pub fn run<H: DispatchEffect>( &mut self, expr: &CoreExpr, handlers: &mut H, ) -> Result<Value, EffectError>

Run an Eff expression to completion with the given handler HList. Backward-compatible: uses U=() (no user data).

pub fn run_with_user<U, H: DispatchEffect<U>>( &mut self, expr: &CoreExpr, handlers: &mut H, user: &U, ) -> Result<Value, EffectError>

Run an Eff expression with user data threaded through to handlers.